@@ -14,7 +14,7 @@ from typing import List, Optional, Sequence, Tuple, Union
 from anchorpoint.textsequences import TextPassage, TextSequence
 from ranges import Range, RangeSet, Inf
 from ranges._helper import _InfiniteValue
-from pydantic import BaseModel, validator, root_validator
+from pydantic import BaseModel, validator
 
 
 class TextSelectionError(Exception):
@@ -275,30 +275,37 @@ class TextPositionSelector(BaseModel):
     def from_range(
         cls, range: Union[Range, TextPositionSelector]
     ) -> TextPositionSelector:
+        """Make TextPositionSelector with same extent as a Range object from python-ranges."""
         if isinstance(range.end, _InfiniteValue):
             end = None
         else:
             end = range.end
         return TextPositionSelector(start=range.start, end=end)
 
-    @validator("start", allow_reuse=True)
+    @validator("start")
     def start_not_negative(cls, v) -> bool:
         """
-        Check if start position is not negative.
+        Verify start position is not negative.
 
         :returns:
-            whether the start position is not negative
+            the start position, which is not negative
         """
         if v < 0:
             raise IndexError("Start position for text range cannot be negative.")
         return v
 
-    @root_validator(allow_reuse=True)
-    def start_less_than_end(cls, values):
-        start, end = values.get("start"), values.get("end")
+    @validator("end")
+    def start_less_than_end(cls, v, values):
+        """
+        Verify start position is before the end position.
+
+        :returns:
+            the end position, which after the start position
+        """
+        start, end = values.get("start"), v
         if end is not None and end <= start:
             raise IndexError("End position must be greater than start position.")
-        return values
+        return v
 
     def range(self) -> Range:
         """Get the range of the text."""
@@ -405,6 +412,7 @@ class TextPositionSelector(BaseModel):
         start: Union[int, str] = 0,
         end: Optional[Union[int, str]] = None,
     ) -> TextPositionSelector:
+        """Make position selector including the text strings "start" and "end" within "text"."""
         if isinstance(start, str):
             start_index = text.find(start)
             if start_index == -1:
@@ -420,6 +428,7 @@ class TextPositionSelector(BaseModel):
         return cls(start=start, end=end)
 
     def subtract_integer(self, value: int) -> TextPositionSelector:
+        """Reduce self's startpoint and endpoint by an integer."""
         new_start = max(0, self.start - value)
 
         if self.end is None:
@@ -444,17 +453,20 @@ class TextPositionSelector(BaseModel):
         return self.subtract_integer(value)
 
     def difference(
-        self, rng: Union[TextPositionSet, TextPositionSelector]
+        self, other: Union[TextPositionSet, TextPositionSelector]
     ) -> Union[TextPositionSet, TextPositionSelector]:
         """
-        Apply Range difference method replacing RangeSet with TextPositionSet in return value.
+        Get selectors in self or other but not both.
+
+        Applies Range difference, method replacing RangeSet
+        with :class:`.TextPositionSet` in return value.
         """
-        if isinstance(rng, TextPositionSet):
-            to_compare: Union[Range, RangeSet] = rng.rangeset()
-        elif isinstance(rng, TextPositionSelector):
-            to_compare = rng.range()
+        if isinstance(other, TextPositionSet):
+            to_compare: Union[Range, RangeSet] = other.rangeset()
+        elif isinstance(other, TextPositionSelector):
+            to_compare = other.range()
         else:
-            to_compare = rng
+            to_compare = other
         new_rangeset = self.rangeset().difference(to_compare)
         if len(new_rangeset.ranges()) == 1:
             return TextPositionSelector.from_range(new_rangeset.ranges()[0])
@@ -532,22 +544,35 @@ class TextPositionSelector(BaseModel):
         return None
 
 
-class TextSelector(BaseModel):
-    __root__: Union[TextQuoteSelector, TextPositionSelector]
-
-
 class TextPositionSet(BaseModel):
-    r"""
-    A set of TextPositionSelectors.
-    """
+    r"""A set of TextPositionSelectors."""
 
     positions: List[TextPositionSelector] = []
     quotes: List[TextQuoteSelector] = []
 
+    @classmethod
+    def from_quotes(
+        self,
+        selection: Union[str, TextQuoteSelector, List[Union[TextQuoteSelector, str]]],
+    ) -> TextPositionSet:
+        """
+        Construct TextPositionSet from string or TextQuoteSelectors.
+
+        If a string is used, it will be converted to a :class:`.TextQuoteSelector` with no prefix or suffix.
+        """
+        if isinstance(selection, (str, TextQuoteSelector)):
+            selection = [selection]
+        selection = [
+            TextQuoteSelector.from_text(s) if isinstance(s, str) else s
+            for s in selection
+        ]
+        return TextPositionSet(quotes=selection)
+
     @classmethod
     def from_ranges(
         cls, ranges: Union[RangeSet, Range, List[Range], List[TextPositionSelector]]
     ) -> TextPositionSet:
+        """Make new class instance from Range objects from python-ranges library."""
         if isinstance(ranges, RangeSet):
             ranges = ranges.ranges()
         if isinstance(ranges, Range):
@@ -717,7 +742,12 @@ class TextPositionSet(BaseModel):
                 selected.append(None)
             for passage in selection_ranges:
                 if passage.start < passage.end and passage.start < len(text):
-                    selected.append(TextPassage(text[passage.start : passage.end]))
+                    string_end = (
+                        passage.end
+                        if not isinstance(passage.end, _InfiniteValue)
+                        else None
+                    )
+                    selected.append(TextPassage(text[passage.start : string_end]))
                 if include_nones and passage.end and (passage.end < len(text)):
                     selected.append(None)
         elif text and include_nones and (not selected or selected[-1] is not None):
@@ -725,18 +755,22 @@ class TextPositionSet(BaseModel):
         return TextSequence(selected)
 
     def rangeset(self) -> RangeSet:
+        """Convert positions into python-ranges Rangeset."""
         ranges = [selector.range() for selector in self.positions]
         return RangeSet(ranges)
 
     def positions_of_quote_selectors(self, text: str) -> List[TextPositionSelector]:
+        """Convert self's quote selectors to position selectors for a given text."""
         return [selector.as_position(text) for selector in self.quotes]
 
     def quotes_rangeset(self, text: str) -> RangeSet:
+        """Get ranges where these quotes appear in the provided text."""
         return RangeSet(
             [selector.range() for selector in self.positions_of_quote_selectors(text)]
         )
 
     def ranges(self) -> List[Range]:
+        """Get positions as Range objects from python-ranges library."""
         return self.rangeset().ranges()
 
     def as_string(self, text: str) -> str:
@@ -759,7 +793,7 @@ class TextPositionSet(BaseModel):
         margin_characters: str = """,."' ;[]()""",
     ) -> TextPositionSet:
         """
-        Expands selected position selectors to include margin of punctuation.
+        Expand selected position selectors to include margin of punctuation.
 
         This can cause multiple selections to be merged into a single one.
 
@@ -777,7 +811,7 @@ class TextPositionSet(BaseModel):
         :returns:
             A new TextPositionSet with the margin added
 
-        >>> from anchorpoint.schemas import TextPositionSetFactory
+        >>> from anchorpoint.textselectors import TextPositionSetFactory
         >>> text = "I predict that the grass is wet. (It rained.)"
         >>> factory = TextPositionSetFactory(text=text)
         >>> selectors = [TextQuoteSelector(exact="the grass is wet"), TextQuoteSelector(exact="it rained")]
@@ -832,13 +866,13 @@ class TextPositionSet(BaseModel):
         :returns:
             The selected text
 
-        >>> from anchorpoint.schemas import TextPositionSetFactory
+        >>> from anchorpoint.textselectors import TextPositionSetFactory
         >>> text = "I predict that the grass is wet. (It rained.)"
         >>> factory = TextPositionSetFactory(text=text)
         >>> selectors = [TextQuoteSelector(exact="the grass is wet"), TextQuoteSelector(exact="it rained")]
         >>> position_set = factory.from_selection(selection=selectors)
         >>> position_set.select_text(text=text)
-        'the grass is wet. (It rained.)'
+        '…the grass is wet. (It rained…'
         """
         with_margin = self.add_margin(
             text=text, margin_width=margin_width, margin_characters=margin_characters
@@ -891,6 +925,8 @@ class TextPositionSetFactory:
 
         First converts strings to TextQuoteSelectors, and then to TextPositionSelectors.
         """
+        if isinstance(selections, TextPositionSet):
+            return selections
         positions = []
         for selection in selections:
             if isinstance(selection, str):
